/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.farm;

import java.awt.event.ActionEvent;
import java.util.HashSet;
import java.util.List;
import java.util.Set;
import javax.swing.AbstractAction;
import nl.cloudfarming.client.model.EntitySavable;
import nl.cloudfarming.client.model.FarmID;
import org.netbeans.api.actions.Savable;
import org.openide.awt.ActionID;
import org.openide.awt.ActionReference;
import org.openide.awt.ActionReferences;
import org.openide.awt.ActionRegistration;
import org.openide.util.NbBundle;

/**
 *
 * @author johan
 */
@ActionID(category = "File", id = "nl.cloudfarming.client.farm.FarmProjectPendingChangesAction")
@ActionRegistration(iconBase = "nl/cloudfarming/client/farm/pending_changes.png",
        displayName = "#CTL_FarmProjectPendingChangesAction")
//@ActionReferences({
//    @ActionReference(path = "Menu/File", position = 700),
//    @ActionReference(path = "FarmProjects/Actions")
//})
@NbBundle.Messages({"CTL_FarmProjectPendingChangesAction=Show pending changes"})
public class FarmProjectPendingChangesAction extends AbstractAction {
    List<FarmProject> projects;

    public FarmProjectPendingChangesAction(List<FarmProject> projects) {
        this.projects = projects;
    }

    @Override
    public void actionPerformed(ActionEvent e) {
        Set<FarmID> farmIDs = new HashSet<>();
        Set<EntitySavable> savables = new HashSet<>();

        for (FarmProject project : projects) {
            farmIDs.add(project.getFarmID());
        }
        
        // collect outstanding changes for selected projects:
        for (EntitySavable savable : Savable.REGISTRY.lookupAll(EntitySavable.class)) {
            if (farmIDs.contains(savable.getFarmID())) {
                savables.add(savable);
            }
        }
        
        if (!savables.isEmpty()) {
            FarmProjectSaveDialog.showDialog(savables);
            // FIXME: discard option needs to be hidden or behave differently from the "close project" version (e.g. Undo).
        } else {
            // TODO: notify or log message "no pending changes"
        }


    }

}
