/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.farm;

import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import javax.swing.Action;
import javax.swing.JComponent;
import javax.swing.JToolBar;
import nl.cloudfarming.client.farm.model.Farm;
import nl.cloudfarming.client.farm.model.FarmDetailsController;
import nl.cloudfarming.client.farm.model.FarmDetailsEditPanel;
import org.netbeans.core.spi.multiview.CloseOperationState;
import org.netbeans.core.spi.multiview.MultiViewElement;
import org.netbeans.core.spi.multiview.MultiViewElementCallback;
import org.openide.awt.UndoRedo;
import org.openide.util.Lookup;
import org.openide.util.NbBundle.Messages;
import org.openide.windows.TopComponent;

@MultiViewElement.Registration(displayName = "#LBL_Farm_PROPERTIES",
iconBase = "nl/cloudfarming/client/farm/house.png",
mimeType = "application/x-agrosense-farm",
persistenceType = TopComponent.PERSISTENCE_NEVER,
preferredID = "FarmVisual",
position = 100)
@Messages({"LBL_Farm_PROPERTIES=Properties",
    "FarmVisualElement name=FarmVisualElement",
    "FarmVisualElement invalid message=There are some errors please correct them"})
public final class FarmVisualElement extends FarmDetailsController<FarmDetailsEditPanel> implements MultiViewElement, PropertyChangeListener {

    private JToolBar toolbar = new JToolBar();
    private transient MultiViewElementCallback callback;
    private Lookup lkp;

    public FarmVisualElement(Lookup lkp) {
        super(new FarmDetailsEditPanel(lkp.lookup(Farm.class)));
        this.lkp = lkp;
        getLookup().lookup(Farm.class).addPropertyChangeListener(this);
    }

    @Override
    public JComponent getVisualRepresentation() {
        return super.getPanel();
    }

    @Override
    public JComponent getToolbarRepresentation() {
        return toolbar;
    }

    @Override
    public Action[] getActions() {
        return new Action[0];
    }

    @Override
    public Lookup getLookup() {
        return lkp;
    }

    @Override
    public void componentOpened() {
    }

    @Override
    public void componentClosed() {
    }

    @Override
    public void componentShowing() {
        if (callback != null) {
            updateName();
        }
    }

    @Override
    public void componentHidden() {
    }

    @Override
    public void componentActivated() {
    }

    @Override
    public void componentDeactivated() {
    }

    @Override
    public UndoRedo getUndoRedo() {
        return UndoRedo.NONE;
    }

    @Override
    public void setMultiViewCallback(MultiViewElementCallback callback) {
        this.callback = callback;
    }

    @Override
    public CloseOperationState canCloseElement() {
        return CloseOperationState.STATE_OK;
    }

    public void updateName() {
        if (callback != null) {
            String name = getLookup().lookup(Farm.class).getName();
            TopComponent tc = callback.getTopComponent();
            tc.setHtmlDisplayName(name);
            tc.setDisplayName(name);
            tc.setName(Bundle.FarmVisualElement_name());
            tc.setToolTipText(Bundle.FarmVisualElement_name());
        }
    }

    @Override
    public void propertyChange(PropertyChangeEvent evt) {
        if (Farm.PROP_NAME.equals(evt.getPropertyName())) {
            updateName();
        }
    }

    @Override
    public void farmDetailFieldsUpdated() {
        if (super.validate()) {
            farmDetailPanel.getErrorPanel().setValid();
        } else {
            farmDetailPanel.getErrorPanel().setError(Bundle.FarmVisualElement_invalid_message());
        }
    }
}
