/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.farm;

import javax.swing.JLabel;
import net.miginfocom.swing.MigLayout;
import nl.cloudfarming.client.util.swing.FormRow;
import org.openide.util.NbBundle;

/**
 * Panel to display a summary of the Farm
 * @author Merijn Zengers
 */
@NbBundle.Messages({"FarmWizardSummaryPanelVisual farmNameValueLabel text=Company name:",
    "FarmWizardSummaryPanelVisual issuingAgencyLabel text=Issuing agency:",
    "FarmWizardSummaryPanelVisual registrationNumberLabel text=Registration number:",
    "FarmWizardSummaryPanelVisual summaryTextLabel text=Below is a summary of the chosen values.",
    "FarmWizardSummaryPanelVisual addressValueLabe text=Address:",
    "FarmWizardSummaryPanelVisual postalcodeValueLabel text=Postal code:",
    "FarmWizardSummaryPanelVisual cityValueLabel text=City:",
    "FarmWizardSummaryPanelVisual coutryValueLabel text=Country:"})
public class FarmWizardSummaryPanelVisual extends javax.swing.JPanel {

    private JLabel farmNameValueLabel;
    private JLabel issuingAgencyValueLabel;
    private JLabel registrationNumberValueLabel;
    private JLabel addressValueLabel;
    private JLabel postalCodeValueLabel;
    private JLabel cityValueLabel;
    private JLabel countryValueLabel;
    

    /**
     * Creates new FarmWizardSummaryPanelVisual
     */
    public FarmWizardSummaryPanelVisual() {
        initComponents();
    }

    /**
     * Get the issuing agency value label
     * @return 
     */
    public JLabel getIssuingAgencyValueLabel() {
        return issuingAgencyValueLabel;
    }

    /**
     * Get the registration number value label
     * @return 
     */
    public JLabel getRegistrationNumberValueLabel() {
        return registrationNumberValueLabel;
    }

    /**
     * Get the city value label
     * @return 
     */
    public JLabel getCityValueLabel() {
        return cityValueLabel;
    }

    /**
     * Get the country value label
     * @return 
     */
    public JLabel getCountryValueLabel() {
        return countryValueLabel;
    }

    /**
     * Get the address value label
     * @return 
     */
    public JLabel getAddresValueLabel() {
        return addressValueLabel;
    }

    /**
     * Get the postal code value label
     * @return 
     */
    public JLabel getPostalCodeValueLabel() {
        return postalCodeValueLabel;
    }


    /**
     * Get the farm name value label
     * @return 
     */
    public JLabel getFarmNameValueLabel() {
        return farmNameValueLabel;
    }
    

    /**
     * This method is called from within the constructor to initialize the form.
     */
    @SuppressWarnings("unchecked")
    private void initComponents() {

        this.setLayout(new MigLayout("wrap"));
        JLabel summaryTextLabel = new JLabel();
        farmNameValueLabel = new JLabel();
        issuingAgencyValueLabel = new JLabel();
        registrationNumberValueLabel = new JLabel();
        addressValueLabel = new JLabel();
        postalCodeValueLabel = new JLabel();
        cityValueLabel = new JLabel();
        countryValueLabel = new JLabel();

        summaryTextLabel.setText(Bundle.FarmWizardSummaryPanelVisual_summaryTextLabel_text());

        FormRow farmNameRow = new FormRow(Bundle.FarmWizardSummaryPanelVisual_farmNameValueLabel_text(), Bundle.FarmWizardSummaryPanelVisual_farmNameValueLabel_text(), farmNameValueLabel);
        FormRow issuingAgencyRow = new FormRow(Bundle.FarmWizardSummaryPanelVisual_issuingAgencyLabel_text(), Bundle.FarmWizardSummaryPanelVisual_issuingAgencyLabel_text(), issuingAgencyValueLabel);
        FormRow registrationNumberRow = new FormRow(Bundle.FarmWizardSummaryPanelVisual_registrationNumberLabel_text(), Bundle.FarmWizardSummaryPanelVisual_registrationNumberLabel_text(), registrationNumberValueLabel);
        FormRow houseNumberAddtionRow = new FormRow(Bundle.FarmWizardSummaryPanelVisual_addressValueLabe_text(), Bundle.FarmWizardSummaryPanelVisual_addressValueLabe_text(), addressValueLabel);
        FormRow postalCodeRow = new FormRow(Bundle.FarmWizardSummaryPanelVisual_postalcodeValueLabel_text(), Bundle.FarmWizardSummaryPanelVisual_postalcodeValueLabel_text(), postalCodeValueLabel);
        FormRow cityRow = new FormRow(Bundle.FarmWizardSummaryPanelVisual_cityValueLabel_text(), Bundle.FarmWizardSummaryPanelVisual_cityValueLabel_text(), cityValueLabel);
        FormRow countryRow = new FormRow(Bundle.FarmWizardSummaryPanelVisual_coutryValueLabel_text(), Bundle.FarmWizardSummaryPanelVisual_coutryValueLabel_text(), countryValueLabel);
        
        this.add(summaryTextLabel);
        this.add(farmNameRow);
        this.add(issuingAgencyRow);
        this.add(registrationNumberRow);
        this.add(houseNumberAddtionRow);
        this.add(postalCodeRow);
        this.add(cityRow);
        this.add(countryRow);
        
    }
}
